DefaultAnimatedContentDelegate class

A default implementation of AnimatedContentDelegate with a scaling animation.

Inheritance

Constructors

DefaultAnimatedContentDelegate({required Widget contentChild})
Creates a DefaultAnimatedContentDelegate.
const

Properties

contentChild Widget
Returns the content child widget associated with this delegate.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context, Animation<double> bookAnimation, Widget? child) Widget
Builds and returns the animated content widget.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited